@@ -27,6 +27,7 @@
 #include "goaprovider-priv.h"
 #include "goaoauthprovider.h"
 #include "goaflickrprovider.h"
+#include "goaobjectskeletonutils.h"
 
 /**
  * GoaFlickrProvider:
@@ -104,25 +105,29 @@ get_consumer_secret (GoaOAuthProvider *oauth_provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/request_token";
+  return "https://www.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/authorize";
+  return "https://www.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/access_token";
+  return "https://www.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
 get_callback_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.gnome.org/goa-1.0/oauth";
+  /* Should match the URI specified in the Flickr App
+   * Garden in order to detect when the user denied access via
+   * the OAuth1 web page.
+   */
+  return "https://www.gnome.org/";
 }
 
 static const gchar *
@@ -335,12 +340,10 @@ build_object (GoaProvider         *provider,
               GError             **error)
 {
   GoaAccount *account;
-  GoaPhotos *photos;
   gboolean photos_enabled;
   gboolean ret;
 
   account = NULL;
-  photos = NULL;
   ret = FALSE;
 
   /* Chain up */
@@ -356,22 +359,8 @@ build_object (GoaProvider         *provider,
   account = goa_object_get_account (GOA_OBJECT (object));
 
   /* Photos */
-  photos = goa_object_get_photos (GOA_OBJECT (object));
   photos_enabled = g_key_file_get_boolean (key_file, group, "PhotosEnabled", NULL);
-
-  if (photos_enabled)
-    {
-      if (photos == NULL)
-        {
-          photos = goa_photos_skeleton_new ();
-          goa_object_skeleton_set_photos (object, photos);
-        }
-    }
-  else
-    {
-      if (photos != NULL)
-        goa_object_skeleton_set_photos (object, NULL);
-    }
+  goa_object_skeleton_attach_photos (object, photos_enabled);
 
   if (just_added)
     {
@@ -386,7 +375,6 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  g_clear_object (&photos);
   g_clear_object (&account);
   return ret;
 }
